@@ -1,4 +1,5 @@
 import logging
+from typing import Dict
 from urllib.parse import urljoin
 
 from .constants import supported_countries
@@ -13,9 +14,12 @@ def get_prices(
     customer_ip: str = None,
     coupons: list = None,
 ) -> dict:
+    """
+    https://developer.paddle.com/api-reference/checkout-api/prices/getprices
+    """
     url = urljoin(self.checkout_v2, 'prices')
 
-    params = {}
+    params: Dict[str, str] = {}
     if product_ids:
         products = ','.join([str(int(product)) for product in product_ids])
         params['product_ids'] = products
