@@ -1,4 +1,5 @@
 import logging
+from typing import Dict, Union
 from urllib.parse import urljoin
 
 log = logging.getLogger(__name__)
@@ -10,15 +11,18 @@ def get_user_history(
     vendor_id: int = None,
     product_id: int = None
 ) -> dict:
+    """
+    https://developer.paddle.com/api-reference/checkout-api/user-history/getuserhistory
+    """
     url = urljoin(self.checkout_v2, 'user/history')
 
-    params = {'email': email}
+    params: Dict[str, Union[str, int]] = {'email': email}
     if product_id:
         params['product_id'] = product_id
 
     if vendor_id:
-        params['vendor_id'] = vendor_id
+        params['vendor_id'] = str(vendor_id)
     else:
-        params['vendor_id'] = self.vendor_id
+        params['vendor_id'] = str(self.vendor_id)
 
     return self.get(url=url, params=params)
