@@ -1,7 +1,9 @@
 from datetime import date, datetime
 
+from .types import DatetimeType
 
-def validate_date(value, field_name):
+
+def validate_date(value: DatetimeType, field_name: str) -> str:
     date_format = '%Y-%m-%d'
     if isinstance(value, str):
         error_message = '{0} must be a datetime/data object or string in format YYYY-MM-DD'.format(field_name)  # NOQA: E501
@@ -17,7 +19,7 @@ def validate_date(value, field_name):
     raise ValueError(error_message)
 
 
-def validate_datetime(value, field_name):
+def validate_datetime(value: DatetimeType, field_name: str) -> str:
     datetime_format = '%Y-%m-%d %H:%M:%S'
     if isinstance(value, str):
         error_message = '{0} must be a datetime object or string in format YYYY-MM-DD HH:MM:SS'.format(field_name)  # NOQA: E501
